=======
Credits
=======

Development Lead
----------------

* Paul McLanahan <pmac@mozilla.com>

Contributors
------------

* Steve Jalim <opensource@stevejalim.mozmail.com>
* Michael Manganiello - https://github.com/adamantike
* Ningú - https://github.com/n1ngu
* blag - https://github.com/blag
* Risson - https://github.com/rissson
* Mariusz Felisiak - https://www.mariuszfelisiak.org/
